@@ -55,7 +55,7 @@ impl StructChunked {
                 if s_len == max_len {
                     new_fields.push(s.clone())
                 } else if s_len == 1 {
-                    new_fields.push(s.expand_at_index(0, max_len))
+                    new_fields.push(s.new_from_index(0, max_len))
                 } else {
                     return Err(PolarsError::ShapeMisMatch(
                         "expected all fields to have equal length".into(),
