@@ -185,8 +185,38 @@ where
         }
         match self.is_sorted2() {
             IsSorted::Ascending | IsSorted::Descending => {
-                let mask = self.not_equal(&self.shift(1));
-                self.filter(&mask)
+                // TODO! optimize this branch
+                if self.null_count() > 0 {
+                    let mut arr = MutablePrimitiveArray::with_capacity(self.len());
+                    let mut iter = self.into_iter();
+                    let mut last = None;
+
+                    if let Some(val) = iter.next() {
+                        last = val;
+                        arr.push(val)
+                    };
+
+                    #[allow(clippy::unnecessary_filter_map)]
+                    let to_extend = iter.filter_map(|opt_val| {
+                        if opt_val != last {
+                            last = opt_val;
+                            Some(opt_val)
+                        } else {
+                            None
+                        }
+                    });
+
+                    arr.extend(to_extend);
+                    let arr: PrimitiveArray<T::Native> = arr.into();
+
+                    Ok(ChunkedArray::from_chunks(
+                        self.name(),
+                        vec![Box::new(arr) as ArrayRef],
+                    ))
+                } else {
+                    let mask = self.not_equal(&self.shift(1));
+                    self.filter(&mask)
+                }
             }
             IsSorted::Not => {
                 let sorted = self.sort(false);
@@ -274,6 +304,60 @@ impl ChunkUnique<Utf8Type> for Utf8Chunked {
     }
 }
 
+#[cfg(feature = "dtype-binary")]
+impl ChunkUnique<BinaryType> for BinaryChunked {
+    fn unique(&self) -> PolarsResult<Self> {
+        match self.null_count() {
+            0 => {
+                let mut set =
+                    PlHashSet::with_capacity(std::cmp::min(HASHMAP_INIT_SIZE, self.len()));
+                for arr in self.downcast_iter() {
+                    set.extend(arr.values_iter())
+                }
+                Ok(BinaryChunked::from_iter_values(
+                    self.name(),
+                    set.iter().copied(),
+                ))
+            }
+            _ => {
+                let mut set =
+                    PlHashSet::with_capacity(std::cmp::min(HASHMAP_INIT_SIZE, self.len()));
+                for arr in self.downcast_iter() {
+                    set.extend(arr.iter())
+                }
+                Ok(BinaryChunked::from_iter_options(
+                    self.name(),
+                    set.iter().copied(),
+                ))
+            }
+        }
+    }
+
+    fn arg_unique(&self) -> PolarsResult<IdxCa> {
+        Ok(IdxCa::from_vec(self.name(), arg_unique_ca!(self)))
+    }
+
+    fn is_unique(&self) -> PolarsResult<BooleanChunked> {
+        is_unique_duplicated!(self, false)
+    }
+    fn is_duplicated(&self) -> PolarsResult<BooleanChunked> {
+        is_unique_duplicated!(self, true)
+    }
+
+    fn n_unique(&self) -> PolarsResult<usize> {
+        if self.null_count() > 0 {
+            Ok(fill_set(self.into_iter().flatten()).len() + 1)
+        } else {
+            Ok(fill_set(self.into_no_null_iter()).len())
+        }
+    }
+
+    #[cfg(feature = "mode")]
+    fn mode(&self) -> PolarsResult<Self> {
+        Ok(mode(self))
+    }
+}
+
 impl ChunkUnique<BooleanType> for BooleanChunked {
     fn unique(&self) -> PolarsResult<Self> {
         // can be None, Some(true), Some(false)
@@ -408,6 +492,25 @@ mod is_first {
             Ok(BooleanChunked::from_chunks(self.name(), chunks))
         }
     }
+
+    #[cfg(feature = "dtype-binary")]
+    impl IsFirst<BinaryType> for BinaryChunked {
+        fn is_first(&self) -> PolarsResult<BooleanChunked> {
+            let mut unique = PlHashSet::new();
+            let chunks = self
+                .downcast_iter()
+                .map(|arr| {
+                    let mask: BooleanArray = arr
+                        .into_iter()
+                        .map(|opt_v| unique.insert(opt_v))
+                        .collect_trusted();
+                    Box::new(mask) as ArrayRef
+                })
+                .collect();
+
+            Ok(BooleanChunked::from_chunks(self.name(), chunks))
+        }
+    }
 }
 
 #[cfg(test)]
