@@ -9,6 +9,8 @@ pub use polars_arrow::kernels::ewm::EWMOptions;
 pub use polars_arrow::prelude::*;
 pub(crate) use polars_arrow::trusted_len::TrustedLen;
 
+#[cfg(feature = "dtype-binary")]
+pub use crate::chunked_array::builder::{BinaryChunkedBuilder, ListBinaryChunkedBuilder};
 pub use crate::chunked_array::builder::{
     BooleanChunkedBuilder, ChunkedBuilder, ListBooleanChunkedBuilder, ListBuilderTrait,
     ListPrimitiveChunkedBuilder, ListUtf8ChunkedBuilder, NewChunkedArray, PrimitiveChunkedBuilder,
