@@ -1,3 +1,6 @@
+#[cfg(feature = "dynamic_groupby")]
+use polars_time::RollingGroupOptions;
+
 use super::*;
 
 #[cfg_attr(not(feature = "dynamic_groupby"), allow(dead_code))]
@@ -5,6 +8,7 @@ pub(crate) struct GroupByRollingExec {
     pub(crate) input: Box<dyn Executor>,
     pub(crate) keys: Vec<Arc<dyn PhysicalExpr>>,
     pub(crate) aggs: Vec<Arc<dyn PhysicalExpr>>,
+    #[cfg(feature = "dynamic_groupby")]
     pub(crate) options: RollingGroupOptions,
     pub(crate) input_schema: SchemaRef,
     pub(crate) slice: Option<(i64, usize)>,
@@ -12,7 +16,11 @@ pub(crate) struct GroupByRollingExec {
 
 impl GroupByRollingExec {
     #[cfg(feature = "dynamic_groupby")]
-    fn execute_impl(&mut self, state: &mut ExecutionState, mut df: DataFrame) -> Result<DataFrame> {
+    fn execute_impl(
+        &mut self,
+        state: &mut ExecutionState,
+        mut df: DataFrame,
+    ) -> PolarsResult<DataFrame> {
         df.as_single_chunk_par();
         state.set_schema(self.input_schema.clone());
 
@@ -20,7 +28,7 @@ impl GroupByRollingExec {
             .keys
             .iter()
             .map(|e| e.evaluate(&df, state))
-            .collect::<Result<Vec<_>>>()?;
+            .collect::<PolarsResult<Vec<_>>>()?;
 
         let (mut time_key, mut keys, groups) = df.groupby_rolling(keys, &self.options)?;
 
@@ -62,7 +70,7 @@ impl GroupByRollingExec {
                     }
                     Ok(agg)
                 })
-                .collect::<Result<Vec<_>>>()
+                .collect::<PolarsResult<Vec<_>>>()
         })?;
 
         state.clear_schema_cache();
@@ -77,12 +85,12 @@ impl GroupByRollingExec {
 
 impl Executor for GroupByRollingExec {
     #[cfg(not(feature = "dynamic_groupby"))]
-    fn execute(&mut self, _state: &mut ExecutionState) -> Result<DataFrame> {
+    fn execute(&mut self, _state: &mut ExecutionState) -> PolarsResult<DataFrame> {
         panic!("activate feature dynamic_groupby")
     }
 
     #[cfg(feature = "dynamic_groupby")]
-    fn execute(&mut self, state: &mut ExecutionState) -> Result<DataFrame> {
+    fn execute(&mut self, state: &mut ExecutionState) -> PolarsResult<DataFrame> {
         #[cfg(debug_assertions)]
         {
             if state.verbose() {
@@ -95,7 +103,7 @@ impl Executor for GroupByRollingExec {
                 .keys
                 .iter()
                 .map(|s| Ok(s.to_field(&self.input_schema)?.name))
-                .collect::<Result<Vec<_>>>()?;
+                .collect::<PolarsResult<Vec<_>>>()?;
             let name = column_delimited("groupby_rolling".to_string(), &by);
             Cow::Owned(name)
         } else {
