@@ -10,7 +10,6 @@ except ImportError:
     # this is only useful for documentation
     warnings.warn("polars binary missing!")
 
-from polars import testing
 from polars.cfg import Config
 from polars.convert import (
     from_arrow,
@@ -72,6 +71,8 @@ from polars.internals.functions import (
     cut,
     date_range,
     get_dummies,
+    ones,
+    zeros,
 )
 from polars.internals.io import read_ipc_schema, read_parquet_schema
 from polars.internals.lazy_functions import _date as date
@@ -224,9 +225,11 @@ __all__ = [
     "concat",
     "date_range",
     "get_dummies",
+    "ones",
     "repeat",
     "element",
     "cut",
+    "zeros",
     # polars.internals.lazy_functions
     "col",
     "count",
@@ -279,7 +282,6 @@ __all__ = [
     "from_arrow",
     "from_pandas",
     # testing
-    "testing",
     "threadpool_size",
     # version
     "show_versions",
