@@ -30,13 +30,10 @@ from polars.datatypes_constructor import (
     polars_type_to_constructor,
     py_type_to_constructor,
 )
-from polars.import_check import (
-    _NUMPY_AVAILABLE,
-    _PYARROW_AVAILABLE,
-    lazy_isinstance,
-    numpy_mod,
-    pyarrow_mod,
-)
+from polars.dependencies import _NUMPY_AVAILABLE, _PYARROW_AVAILABLE
+from polars.dependencies import numpy as np
+from polars.dependencies import pandas as pd
+from polars.dependencies import pyarrow as pa
 from polars.utils import threadpool_size
 
 if version_info >= (3, 10):
@@ -59,10 +56,6 @@ except ImportError:
 
 
 if TYPE_CHECKING:
-    import numpy as np
-    import pandas as pd
-    import pyarrow as pa
-
     from polars.internals.type_aliases import Orientation
 
 
@@ -89,7 +82,6 @@ def arrow_to_pyseries(name: str, values: pa.Array, rechunk: bool = True) -> PySe
     array = coerce_arrow(values)
 
     # special handling of empty categorical arrays
-    pa = pyarrow_mod()
     if (
         len(array) == 0
         and isinstance(array.type, pa.DictionaryType)
@@ -127,8 +119,6 @@ def numpy_to_pyseries(
     nan_to_null: bool = False,
 ) -> PySeries:
     """Construct a PySeries from a numpy array."""
-    import numpy as np
-
     if not values.flags["C_CONTIGUOUS"]:
         values = np.array(values)
 
@@ -272,16 +262,7 @@ def sequence_to_pyseries(
                     ._s
                 )
 
-            # TODO: use anyvalues here
-            # no need to require pyarrow for this.
-            if not _PYARROW_AVAILABLE:  # pragma: no cover
-                raise ImportError(
-                    "'pyarrow' is required for converting a Sequence of date or"
-                    " datetime values to a PySeries."
-                )
-            pa = pyarrow_mod()
-            # let arrow infer dtype if not timedelta
-            # arrow uses microsecond durations by default, not supported yet.
+            # TODO: use anyvalues here (no need to require pyarrow for this).
             arrow_dtype = dtype_to_arrow_type(dtype)
             return arrow_to_pyseries(name, pa.array(values, type=arrow_dtype))
 
@@ -324,7 +305,6 @@ def sequence_to_pyseries(
                             return PySeries.new_list(name, values, dtype)
                 # pass; we create an object if we get here
             else:
-                pa = pyarrow_mod()
                 try:
                     to_arrow_type = (
                         dtype_to_arrow_type
@@ -412,7 +392,6 @@ def _pandas_series_to_arrow(
     :class:`pyarrow.Array`
 
     """
-    pa = pyarrow_mod()
     dtype = getattr(values, "dtype", None)
     if dtype == "object" and len(values) > 0:
         first_non_none = _get_first_non_none(values.values)  # type: ignore[arg-type]
@@ -438,10 +417,6 @@ def pandas_to_pyseries(
     name: str, values: pd.Series | pd.DatetimeIndex, nan_to_none: bool = True
 ) -> PySeries:
     """Construct a PySeries from a pandas Series or DatetimeIndex."""
-    if not _PYARROW_AVAILABLE:  # pragma: no cover
-        raise ImportError(
-            "'pyarrow' is required when constructing a PySeries from a pandas Series."
-        )
     # TODO: Change `if not name` to `if name is not None` once name is Optional[str]
     if not name and values.name is not None:
         name = str(values.name)
@@ -542,18 +517,13 @@ def dict_to_pydf(
         return PyDataFrame(data_series)
 
     if _NUMPY_AVAILABLE:
-        all_numpy = True
+        count_numpy = 0
         for val in data.values():
             # only start a thread pool from a reasonable size.
-            all_numpy = (
-                all_numpy
-                and lazy_isinstance(val, "numpy", lambda: numpy_mod().ndarray)
-                and len(val) > 1000
-            )
-            if not all_numpy:
-                break
+            count_numpy += int(isinstance(val, np.ndarray) and len(val) > 1000)
 
-        if all_numpy:
+        # if we have more than 3 numpy arrays we multi-thread
+        if count_numpy > 2:
             # yes, multi-threading was easier in python here
             # we cannot run multiple threads that run python code
             # and release the gil in pyo3
@@ -563,11 +533,11 @@ def dict_to_pydf(
             import multiprocessing.dummy
 
             pool_size = threadpool_size()
-            pool = multiprocessing.dummy.Pool(pool_size)
-            data_series = pool.map(
-                lambda t: pli.Series(t[0], t[1])._s,
-                [(k, v) for k, v in data.items()],
-            )
+            with multiprocessing.dummy.Pool(pool_size) as pool:
+                data_series = pool.map(
+                    lambda t: pli.Series(t[0], t[1])._s,
+                    [(k, v) for k, v in data.items()],
+                )
             return PyDataFrame(data_series)
 
     # fast path
@@ -738,11 +708,6 @@ def arrow_to_pydf(
     data: pa.Table, columns: ColumnsType | None = None, rechunk: bool = True
 ) -> PyDataFrame:
     """Construct a PyDataFrame from an Arrow Table."""
-    if not _PYARROW_AVAILABLE:  # pragma: no cover
-        raise ImportError(
-            "'pyarrow' is required when constructing a PyDataFrame from an Arrow Table."
-        )
-    pa = pyarrow_mod()
     original_columns = columns
     if columns is not None:
         columns, dtypes = _unpack_columns(columns)
@@ -825,12 +790,6 @@ def pandas_to_pydf(
     nan_to_none: bool = True,
 ) -> PyDataFrame:
     """Construct a PyDataFrame from a pandas DataFrame."""
-    if not _PYARROW_AVAILABLE:  # pragma: no cover
-        raise ImportError(
-            "'pyarrow' is required when constructing a PyDataFrame from a pandas"
-            " DataFrame."
-        )
-    pa = pyarrow_mod()
     length = data.shape[0]
     arrow_dict = {
         str(col): _pandas_series_to_arrow(
@@ -843,7 +802,6 @@ def pandas_to_pydf(
 
 
 def coerce_arrow(array: pa.Array, rechunk: bool = True) -> pa.Array:
-    pa = pyarrow_mod()
     # note: Decimal256 could not be cast to float
     if isinstance(array.type, pa.Decimal128Type):
         array = pa.compute.cast(array, pa.float64())
