@@ -250,7 +250,7 @@ class ExprListNameSpace:
         other_list.insert(0, pli.wrap_expr(self._pyexpr))
         return pli.concat_list(other_list)
 
-    def get(self, index: int) -> pli.Expr:
+    def get(self, index: int | pli.Expr | str) -> pli.Expr:
         """
         Get the value by index in the sublists.
 
@@ -281,8 +281,12 @@ class ExprListNameSpace:
         └──────┘
 
         """
+        index = pli.expr_to_lit_or_expr(index, str_to_lit=False)._pyexpr
         return pli.wrap_expr(self._pyexpr.lst_get(index))
 
+    def __getitem__(self, item: int) -> pli.Expr:
+        return self.get(item)
+
     def first(self) -> pli.Expr:
         """
         Get the first value of the sublists.
