@@ -506,6 +506,10 @@ impl PyExpr {
         self.clone().inner.product().into()
     }
 
+    pub fn shrink_dtype(&self) -> PyExpr {
+        self.inner.clone().shrink_dtype().into()
+    }
+
     pub fn str_parse_date(&self, fmt: Option<String>, strict: bool, exact: bool) -> PyExpr {
         self.inner
             .clone()
@@ -902,6 +906,10 @@ impl PyExpr {
         self.inner.clone().dt().cast_time_zone(tz).into()
     }
 
+    pub fn dt_tz_localize(&self, tz: String) -> PyExpr {
+        self.inner.clone().dt().tz_localize(tz).into()
+    }
+
     pub fn dt_truncate(&self, every: &str, offset: &str) -> PyExpr {
         self.inner.clone().dt().truncate(every, offset).into()
     }
@@ -1044,7 +1052,12 @@ impl PyExpr {
             .into()
     }
 
-    pub fn map(&self, lambda: PyObject, output_type: &PyAny, agg_list: bool) -> PyExpr {
+    pub fn map(
+        &self,
+        lambda: PyObject,
+        output_type: Option<Wrap<DataType>>,
+        agg_list: bool,
+    ) -> PyExpr {
         map_single(self, lambda, output_type, agg_list)
     }
 
@@ -1302,7 +1315,10 @@ impl PyExpr {
         self.inner
             .clone()
             .arr()
-            .sort(reverse)
+            .sort(SortOptions {
+                descending: reverse,
+                ..Default::default()
+            })
             .with_fmt("arr.sort")
             .into()
     }
@@ -1325,8 +1341,8 @@ impl PyExpr {
             .into()
     }
 
-    fn lst_get(&self, index: i64) -> Self {
-        self.inner.clone().arr().get(index).into()
+    fn lst_get(&self, index: PyExpr) -> Self {
+        self.inner.clone().arr().get(index.inner).into()
     }
 
     fn lst_join(&self, separator: &str) -> Self {
