@@ -13,16 +13,14 @@ import pytest
 
 import polars as pl
 from polars.datatypes import DTYPE_TEMPORAL_UNITS
+from polars.dependencies import zoneinfo
 from polars.exceptions import NoRowsReturned, TooManyRowsReturned
-from polars.import_check import zoneinfo_mod
 from polars.testing import assert_frame_equal, assert_series_equal
-from polars.testing._parametric import columns
+from polars.testing.parametric import columns
 
 if TYPE_CHECKING:
     from polars.internals.type_aliases import JoinStrategy
 
-zoneinfo = zoneinfo_mod()
-
 
 def test_version() -> None:
     pl.__version__
@@ -679,8 +677,9 @@ def test_extend() -> None:
 
 def test_drop() -> None:
     df = pl.DataFrame({"a": [2, 1, 3], "b": ["a", "b", "c"], "c": [1, 2, 3]})
-    df = df.drop(name="a")  # type: ignore[call-arg]
-    assert df.shape == (3, 2)
+    with pytest.deprecated_call():
+        df = df.drop(name="a")  # type: ignore[call-arg]
+        assert df.shape == (3, 2)
     df = pl.DataFrame({"a": [2, 1, 3], "b": ["a", "b", "c"], "c": [1, 2, 3]})
     df = df.drop(columns="a")
     assert df.shape == (3, 2)
@@ -1321,9 +1320,9 @@ def test_reproducible_hash_with_seeds() -> None:
     expected = pl.Series(
         "s",
         [
-            15801072432137883943,
+            8823051245921001677,
             988796329533502010,
-            9604537446374444741,
+            7528667241828618484,
         ],
         dtype=pl.UInt64,
     )
@@ -1945,6 +1944,18 @@ def test_get_item() -> None:
     with pytest.raises(ValueError):
         df[pl.Series([True, False, True]), "b"]
 
+    # 5343
+    df = pl.DataFrame(
+        {
+            f"fo{col}": [n**col for n in range(5)]  # 5 rows
+            for col in range(12)  # 12 columns
+        }
+    )
+    assert df[4, 4] == 256
+    assert df[4, 5] == 1024
+    assert df[4, [2]].frame_equal(pl.DataFrame({"fo2": [16]}))
+    assert df[4, [5]].frame_equal(pl.DataFrame({"fo5": [1024]}))
+
 
 @pytest.mark.parametrize("as_series,inner_dtype", [(True, pl.Series), (False, list)])
 def test_to_dict(as_series: bool, inner_dtype: Any) -> None:
