@@ -2,7 +2,6 @@ from __future__ import annotations
 
 from datetime import datetime
 from typing import Any, cast, no_type_check
-from unittest.mock import patch
 
 import numpy as np
 import pandas as pd
@@ -313,17 +312,22 @@ def test_from_pandas_series() -> None:
 
 
 def test_from_optional_not_available() -> None:
-    with patch("polars.convert._NUMPY_AVAILABLE", False):
-        with pytest.raises(ImportError):
-            pl.from_numpy(np.array([[1, 2], [3, 4]]), columns=["a", "b"])
-    with patch("polars.convert._PYARROW_AVAILABLE", False):
-        with pytest.raises(ImportError):
-            pl.from_arrow(pa.table({"a": [1, 2, 3], "b": [4, 5, 6]}))
-        with pytest.raises(ImportError):
-            pl.from_pandas(pd.Series([1, 2, 3]))
-    with patch("polars.convert._PANDAS_AVAILABLE", False):
-        with pytest.raises(ImportError):
-            pl.from_pandas(pd.Series([1, 2, 3]))
+    from polars.dependencies import _proxy_module
+
+    # proxy module is created dynamically if the required module is not available
+    # (see the polars.dependencies source code for additional detail/comments)
+
+    np = _proxy_module("numpy", register=False)
+    with pytest.raises(ImportError, match=r"np\.array requires 'numpy'"):
+        pl.from_numpy(np.array([[1, 2], [3, 4]]), columns=["a", "b"])
+
+    pa = _proxy_module("pyarrow", register=False)
+    with pytest.raises(ImportError, match=r"pa\.table requires 'pyarrow'"):
+        pl.from_arrow(pa.table({"a": [1, 2, 3], "b": [4, 5, 6]}))
+
+    pd = _proxy_module("pandas", register=False)
+    with pytest.raises(ImportError, match=r"pd\.Series requires 'pandas'"):
+        pl.from_pandas(pd.Series([1, 2, 3]))
 
 
 def test_upcast_pyarrow_dicts() -> None:
