@@ -106,7 +106,7 @@ def test_init_inputs(monkeypatch: Any) -> None:
         pl.Series("bigint", [2**64])
 
     # numpy not available
-    monkeypatch.setattr(pl.internals.series.series, "_NUMPY_AVAILABLE", False)
+    monkeypatch.setattr(pl.internals.series.series, "_NUMPY_TYPE", lambda x: False)
     with pytest.raises(ValueError):
         pl.DataFrame(np.array([1, 2, 3]), columns=["a"])
 
@@ -385,12 +385,13 @@ def test_various() -> None:
 
 def test_filter_ops() -> None:
     a = pl.Series("a", range(20))
-    assert a[a > 1].len() == 18
-    assert a[a < 1].len() == 1
-    assert a[a <= 1].len() == 2
-    assert a[a >= 1].len() == 19
-    assert a[a == 1].len() == 1
-    assert a[a != 1].len() == 19
+    with pytest.deprecated_call(match="passing a boolean mask to Series.__getitem__"):
+        assert a[a > 1].len() == 18
+        assert a[a < 1].len() == 1
+        assert a[a <= 1].len() == 2
+        assert a[a >= 1].len() == 19
+        assert a[a == 1].len() == 1
+        assert a[a != 1].len() == 19
 
 
 def test_cast() -> None:
